Module errors

The error module contains all the data structures that represent an error.

Structs

InstructionError
Structure to represent the errors for instructions.
WasmValueNativeCastError
Structure to represent errors when casting from an InterfaceType to a native value.

Enums

InstructionErrorKind
The kind of instruction errors.

Type Aliases

InstructionResult
A type alias for instruction’s results.
InterpreterResult
A type alias for the interpreter result.