Module values

Module values 

Defines WIT values and associated operations.

Enums

InterfaceValue
A WIT value.

Traits

NativeType
Represents a native type supported by WIT.

Functions

from_interface_values
Deserialize a set of InterfaceValues to a type T that implements the Deserialize trait.
to_interface_value
Serialize a type T that implements the Serialize trait to an InterfaceValue.